<?php

namespace B2buy\Order\Http\Controllers;

use App\Http\Controllers\APIController as BaseController;
use B2buy\Order\Http\Requests\OrderProductRequest;
use B2buy\Order\Interfaces\OrderProductRepositoryInterface;
use B2buy\Order\Models\OrderProduct;
use B2buy\Order\Forms\OrderProduct as Form;

/**
 * APIController  class for order_product.
 */
class OrderProductAPIController extends BaseController
{

    /**
     * Initialize order_product resource controller.
     *
     * @param type OrderProductRepositoryInterface $order_product
     *
     * @return null
     */
    public function __construct(OrderProductRepositoryInterface $order_product)
    {
        parent::__construct();
        $this->repository = $order_product;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\B2buy\Order\Repositories\Criteria\OrderProductResourceCriteria::class);
    }

    /**
     * Display a list of order_product.
     *
     * @return Response
     */
    public function index(OrderProductRequest $request)
    {
        return $this->repository
            ->setPresenter(\B2buy\Order\Repositories\Presenter\OrderProductPresenter::class)
            ->paginate();
    }

    /**
     * Display order_product.
     *
     * @param Request $request
     * @param Model   $order_product
     *
     * @return Response
     */
    public function show(OrderProductRequest $request, OrderProduct $order_product)
    {
        return $order_product->setPresenter(\B2buy\Order\Repositories\Presenter\OrderProductListPresenter::class);
        ;
    }

    /**
     * Create new order_product.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(OrderProductRequest $request)
    {
        try {
            $data              = $request->all();
            $data['user_id']   = user_id();
            $data['user_type'] = user_type();
            $data              = $this->repository->create($data);
            $message           = trans('messages.success.created', ['Module' => trans('order::order_product.name')]);
            $code              = 204;
            $status            = 'success';
            $url               = guard_url('order/order_product/' . $order_product->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('order/order_product');
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Update the order_product.
     *
     * @param Request $request
     * @param Model   $order_product
     *
     * @return Response
     */
    public function update(OrderProductRequest $request, OrderProduct $order_product)
    {
        try {
            $data = $request->all();

            $order_product->update($data);
            $message = trans('messages.success.updated', ['Module' => trans('order::order_product.name')]);
            $code    = 204;
            $status  = 'success';
            $url     = guard_url('order/order_product/' . $order_product->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('order/order_product/' . $order_product->getRouteKey());
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Remove the order_product.
     *
     * @param Model   $order_product
     *
     * @return Response
     */
    public function destroy(OrderProductRequest $request, OrderProduct $order_product)
    {
        try {
            $order_product->delete();
            $message = trans('messages.success.deleted', ['Module' => trans('order::order_product.name')]);
            $code    = 202;
            $status  = 'success';
            $url     = guard_url('order/order_product/0');
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('order/order_product/' . $order_product->getRouteKey());
        }
        return compact('message', 'code', 'status', 'url');
    }

    /**
     * Return the form elements as json.
     *
     * @param String   $element
     *
     * @return json
     */
    public function form($element = 'fields')
    {
        $form = new Form();
        return $form->form($element, true);
    }

}
