<?php

namespace B2buy\Order\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use B2buy\Order\Http\Requests\OrderProductRequest;
use B2buy\Order\Models\OrderProduct;

/**
 * Admin web controller class.
 */
class OrderProductWorkflowController extends BaseController
{

    /**
     * Workflow controller function for order_product.
     *
     * @param Model   $order_product
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(OrderProductRequest $request, OrderProduct $order_product, $step)
    {

        try {

            $order_product->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('order::order_product.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/order_product/order_product/' . $order_product->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/order_product/order_product/' . $order_product->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for order_product.
     *
     * @param Model   $order_product
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
     */

    public function getWorkflow(OrderProduct $order_product, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $order_product->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('order::order_product.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('order::admin.order_product.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('order::admin.order_product.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('order::admin.order_product.message', $data)->render();

        }

    }
}
