<?php

namespace B2buy\Order\Policies;

use Litepie\User\Contracts\UserPolicy;
use B2buy\Order\Models\OrderProduct;

class OrderProductPolicy
{

    /**
     * Determine if the given user can view the order_product.
     *
     * @param UserPolicy $user
     * @param OrderProduct $order_product
     *
     * @return bool
     */
    public function view(UserPolicy $user, OrderProduct $order_product)
    {
        if ($user->canDo('order.order_product.view') && $user->isAdmin()) {
            return true;
        }

        return $order_product->user_id == user_id() && $order_product->user_type == user_type();
    }

    /**
     * Determine if the given user can create a order_product.
     *
     * @param UserPolicy $user
     * @param OrderProduct $order_product
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('order.order_product.create');
    }

    /**
     * Determine if the given user can update the given order_product.
     *
     * @param UserPolicy $user
     * @param OrderProduct $order_product
     *
     * @return bool
     */
    public function update(UserPolicy $user, OrderProduct $order_product)
    {
        if ($user->canDo('order.order_product.edit') && $user->isAdmin()) {
            return true;
        }

        return $order_product->user_id == user_id() && $order_product->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given order_product.
     *
     * @param UserPolicy $user
     * @param OrderProduct $order_product
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, OrderProduct $order_product)
    {
        return $order_product->user_id == user_id() && $order_product->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given order_product.
     *
     * @param UserPolicy $user
     * @param OrderProduct $order_product
     *
     * @return bool
     */
    public function verify(UserPolicy $user, OrderProduct $order_product)
    {
        if ($user->canDo('order.order_product.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given order_product.
     *
     * @param UserPolicy $user
     * @param OrderProduct $order_product
     *
     * @return bool
     */
    public function approve(UserPolicy $user, OrderProduct $order_product)
    {
        if ($user->canDo('order.order_product.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
