<?php

namespace B2buy\Order\Providers;

use Litepie\Contracts\Workflow\Workflow as WorkflowContract;
use Litepie\Foundation\Support\Providers\WorkflowServiceProvider as ServiceProvider;

class WorkflowServiceProvider extends ServiceProvider
{
    /**
     * The validators mappings for the package.
     *
     * @var array
     */
    protected $validators = [
        // Bind Order workflow validator
        'B2buy\Order\Models\Order' => \B2buy\Order\Workflow\OrderValidator::class,

        // Bind OrderProduct workflow validator
        'B2buy\Order\Models\OrderProduct' => \B2buy\Order\Workflow\OrderProductValidator::class,
    ];

    /**
     * The actions mappings for the package.
     *
     * @var array
     */
    protected $actions = [
        // Bind Order workflow actions
        'B2buy\Order\Models\Order' => \B2buy\Order\Workflow\OrderAction::class,

        // Bind OrderProduct workflow actions
        'B2buy\Order\Models\OrderProduct' => \B2buy\Order\Workflow\OrderProductAction::class,
    ];

    /**
     * The notifiers mappings for the package.
     *
     * @var array
     */
    protected $notifiers = [
       // Bind Order workflow notifiers
        'B2buy\Order\Models\Order' => \B2buy\Order\Workflow\OrderNotifier::class,

        // Bind OrderProduct workflow notifiers
        'B2buy\Order\Models\OrderProduct' => \B2buy\Order\Workflow\OrderProductNotifier::class,
    ];

    /**
     * Register any package workflow validation services.
     *
     * @param \Litepie\Contracts\Workflow\Workflow $workflow
     *
     * @return void
     */
    public function boot(WorkflowContract $workflow)
    {
        parent::registerValidators($workflow);
        parent::registerActions($workflow);
        parent::registerNotifiers($workflow);
    }
}
