<?php

namespace B2buy\Order\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use B2buy\Order\Models\OrderProduct;

class OrderProductAction
{
    /**
     * Perform the complete action.
     *
     * @param OrderProduct $order_product
     *
     * @return OrderProduct
     */
    public function complete(OrderProduct $order_product)
    {
        try {
            $order_product->status = 'complete';
            return $order_product->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param OrderProduct $order_product
     *
     * @return OrderProduct
     */public function verify(OrderProduct $order_product)
    {
        try {
            $order_product->status = 'verify';
            return $order_product->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param OrderProduct $order_product
     *
     * @return OrderProduct
     */public function approve(OrderProduct $order_product)
    {
        try {
            $order_product->status = 'approve';
            return $order_product->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param OrderProduct $order_product
     *
     * @return OrderProduct
     */public function publish(OrderProduct $order_product)
    {
        try {
            $order_product->status = 'publish';
            return $order_product->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param OrderProduct $order_product
     *
     * @return OrderProduct
     */
    public function archive(OrderProduct $order_product)
    {
        try {
            $order_product->status = 'archive';
            return $order_product->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param OrderProduct $order_product
     *
     * @return OrderProduct
     */
    public function unpublish(OrderProduct $order_product)
    {
        try {
            $order_product->status = 'unpublish';
            return $order_product->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
