<?php

namespace B2buy\Order\Workflow;

use B2buy\Order\Models\OrderProduct;
use Validator;

class OrderProductValidator
{

    /**
     * Determine if the given order_product is valid for complete status.
     *
     * @param OrderProduct $order_product
     *
     * @return bool / Validator
     */
    public function complete(OrderProduct $order_product)
    {
        return Validator::make($order_product->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given order_product is valid for verify status.
     *
     * @param OrderProduct $order_product
     *
     * @return bool / Validator
     */
    public function verify(OrderProduct $order_product)
    {
        return Validator::make($order_product->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given order_product is valid for approve status.
     *
     * @param OrderProduct $order_product
     *
     * @return bool / Validator
     */
    public function approve(OrderProduct $order_product)
    {
        return Validator::make($order_product->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given order_product is valid for publish status.
     *
     * @param OrderProduct $order_product
     *
     * @return bool / Validator
     */
    public function publish(OrderProduct $order_product)
    {
        return Validator::make($order_product->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given order_product is valid for archive status.
     *
     * @param OrderProduct $order_product
     *
     * @return bool / Validator
     */
    public function archive(OrderProduct $order_product)
    {
        return Validator::make($order_product->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given order_product is valid for unpublish status.
     *
     * @param OrderProduct $order_product
     *
     * @return bool / Validator
     */
    public function unpublish(OrderProduct $order_product)
    {
        return Validator::make($order_product->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
